@@ -133,6 +133,7 @@ varpoord <- function(Y, w_final,
                if (length(q) != nrow(datasetX))  stop("'q' does not exist in 'datasetX'!") }
           if (min(q %in% names(datasetX))==1) q <- datasetX[, q, with=FALSE]  }
     }
+  N <- dataset <- datasetX <- NULL
 
   # Y
   Y <- data.frame(Y)
@@ -342,9 +343,10 @@ varpoord <- function(Y, w_final,
     if (any(is.na(X_ID_household))) stop("'X_ID_household' has unknown values")
 
     IDh <- data.table(unique(ID_household))
-    if (!is.null(period)) {X_ID_household <- data.table(periodX, X_ID_household)
-                           IDh <- data.table(unique(data.table(period, ID_household)))}
-    if (any(duplicated(X_ID_household))) stop("'X_ID_household' have duplicates")
+    if (!is.null(period)) { X_ID_household <- data.table(periodX, X_ID_household)
+                            IDh <- data.table(period, ID_household)
+                            IDh <- IDh[, .N, by=names(IDh)][, N:=NULL] }
+    if (nrow(X_ID_household[,.N,by=names(X_ID_household)][N>1])>0) stop("'X_ID_household' have duplicates")
     setkeyv(X_ID_household, names(X_ID_household))
     setkeyv(IDh, names(IDh))
 
